@@ -198,49 +198,49 @@ namespace
     BglDictionary( string const & id, string const & indexFile,
                    string const & dictionaryFile );
 
-    virtual string getName() noexcept
+    string getName() noexcept override
     { return dictionaryName; }
 
-    virtual map< Dictionary::Property, string > getProperties() noexcept
+    map< Dictionary::Property, string > getProperties() noexcept override
     { return map< Dictionary::Property, string >(); }
 
-    virtual unsigned long getArticleCount() noexcept
+    unsigned long getArticleCount() noexcept override
     { return idxHeader.articleCount; }
 
-    virtual unsigned long getWordCount() noexcept
+    unsigned long getWordCount() noexcept override
     { return idxHeader.wordCount; }
 
-    inline virtual quint32 getLangFrom() const
+    inline quint32 getLangFrom() const override
     { return idxHeader.langFrom; }
 
-    inline virtual quint32 getLangTo() const
+    inline quint32 getLangTo() const override
     { return idxHeader.langTo; }
 
-    virtual sptr< Dictionary::WordSearchRequest > findHeadwordsForSynonym( wstring const & )
+    sptr< Dictionary::WordSearchRequest > findHeadwordsForSynonym( wstring const & ) override
       ;
 
-    virtual sptr< Dictionary::DataRequest > getArticle( wstring const &,
+    sptr< Dictionary::DataRequest > getArticle( wstring const &,
                                                         vector< wstring > const & alts,
                                                         wstring const &,
-                                                        bool ignoreDiacritics )
+                                                        bool ignoreDiacritics ) override
       ;
 
-    virtual sptr< Dictionary::DataRequest > getResource( string const & name )
+    sptr< Dictionary::DataRequest > getResource( string const & name ) override
       ;
 
-    virtual sptr< Dictionary::DataRequest > getSearchResults( QString const & searchString,
+    sptr< Dictionary::DataRequest > getSearchResults( QString const & searchString,
                                                               int searchMode, bool matchCase,
                                                               int distanceBetweenWords,
                                                               int maxResults,
                                                               bool ignoreWordsOrder,
-                                                              bool ignoreDiacritics );
-    virtual QString const& getDescription();
+                                                              bool ignoreDiacritics ) override;
+    QString const& getDescription() override;
 
-    virtual void getArticleText( uint32_t articleAddress, QString & headword, QString & text );
+    void getArticleText( uint32_t articleAddress, QString & headword, QString & text ) override;
 
-    virtual void makeFTSIndex(QAtomicInt & isCancelled, bool firstIteration );
+    void makeFTSIndex(QAtomicInt & isCancelled, bool firstIteration ) override;
 
-    virtual void setFTSParameters( Config::FullTextSearch const & fts )
+    void setFTSParameters( Config::FullTextSearch const & fts ) override
     {
       can_FTS = fts.enabled
                 && !fts.disabledTypes.contains( "BGL", Qt::CaseInsensitive )
@@ -249,7 +249,7 @@ namespace
 
   protected:
 
-    virtual void loadIcon() noexcept;
+    void loadIcon() noexcept override;
 
   private:
 
@@ -509,7 +509,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class BglHeadwordsRequest: public Dictionary::WordSearchRequest
@@ -534,7 +534,7 @@ public:
 
   void run(); // Run from another thread by BglHeadwordsRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -656,7 +656,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class BglArticleRequest: public Dictionary::DataRequest
@@ -684,7 +684,7 @@ public:
 
   void run(); // Run from another thread by BglArticleRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -890,20 +890,20 @@ void BglArticleRequest::run()
 
   result = QString::fromUtf8( result.c_str() )
           // onclick location to link
-          .replace( QRegularExpression( "<([a-z0-9]+)\\s+[^>]*onclick=\"[a-z.]*location(?:\\.href)\\s*=\\s*'([^']+)[^>]*>([^<]+)</\\1>",
+          .replace( QRegularExpression( R"(<([a-z0-9]+)\s+[^>]*onclick="[a-z.]*location(?:\.href)\s*=\s*'([^']+)[^>]*>([^<]+)</\1>)",
                                         QRegularExpression::CaseInsensitiveOption ),
-                    "<a href=\"\\2\">\\3</a>")
-           .replace( QRegularExpression( "(<\\s*a\\s+[^>]*href\\s*=\\s*[\"']\\s*)bword://",
+                    R"(<a href="\2">\3</a>)")
+           .replace( QRegularExpression( R"((<\s*a\s+[^>]*href\s*=\s*["']\s*)bword://)",
                                          QRegularExpression::CaseInsensitiveOption ),
                      "\\1bword:" )
           //remove invalid width, height attrs
-          .replace( QRegularExpression( "(width|height)\\s*=\\s*[\"']\\d{7,}[\"'']" ),
+          .replace( QRegularExpression( R"((width|height)\s*=\s*["']\d{7,}["''])" ),
                    "" )
           //remove invalid <br> tag
-          .replace( QRegularExpression( "<br>(<div|<table|<tbody|<tr|<td|</div>|</table>|</tbody>|</tr>|</td>|function addScript|var scNode|scNode|var atag|while\\(atag|atag=atag|document\\.getElementsByTagName|addScript|src=\"bres|<a onmouseover=\"return overlib|onclick=\"return overlib)",
+          .replace( QRegularExpression( R"(<br>(<div|<table|<tbody|<tr|<td|</div>|</table>|</tbody>|</tr>|</td>|function addScript|var scNode|scNode|var atag|while\(atag|atag=atag|document\.getElementsByTagName|addScript|src="bres|<a onmouseover="return overlib|onclick="return overlib))",
                                         QRegularExpression::CaseInsensitiveOption ),
                     "\\1" )
-          .replace( QRegularExpression( "(AUTOSTATUS, WRAP\\);\" |</DIV>|addScript\\('JS_FILE_PHONG_VT_45634'\\);|appendChild\\(scNode\\);|atag\\.firstChild;)<br>",
+          .replace( QRegularExpression( R"((AUTOSTATUS, WRAP\);" |</DIV>|addScript\('JS_FILE_PHONG_VT_45634'\);|appendChild\(scNode\);|atag\.firstChild;)<br>)",
                                         QRegularExpression::CaseInsensitiveOption ),
                     " \\1 " )
            .toUtf8().data();
@@ -951,7 +951,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class BglResourceRequest: public Dictionary::DataRequest
@@ -985,7 +985,7 @@ public:
 
   void run(); // Run from another thread by BglResourceRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -1079,7 +1079,7 @@ sptr< Dictionary::DataRequest > BglDictionary::getResource( string const & name
   {
     QString str = QString::fromUtf8( text.c_str() );
 
-    QRegularExpression charsetExp( "<\\s*charset\\s+c\\s*=\\s*[\"']?t[\"']?\\s*>((?:\\s*[0-9a-fA-F]+\\s*;\\s*)*)<\\s*/\\s*charset\\s*>",
+    QRegularExpression charsetExp( R"(<\s*charset\s+c\s*=\s*["']?t["']?\s*>((?:\s*[0-9a-fA-F]+\s*;\s*)*)<\s*/\s*charset\s*>)",
                                    QRegularExpression::CaseInsensitiveOption
                                    | QRegularExpression::InvertedGreedinessOption );
 
@@ -1126,8 +1126,8 @@ sptr< Dictionary::DataRequest > BglDictionary::getResource( string const & name
     { return resources; }
 
   protected:
-    virtual void handleBabylonResource( string const & filename,
-                                        char const * data, size_t size );
+    void handleBabylonResource( string const & filename,
+                                        char const * data, size_t size ) override;
   };
 
   void ResourceHandler::handleBabylonResource( string const & filename,
