@@ -67,39 +67,39 @@ public:
   {
   }
 
-  virtual string getName() noexcept
+  string getName() noexcept override
   { return name; }
 
-  virtual map< Property, string > getProperties() noexcept
+  map< Property, string > getProperties() noexcept override
   { return map< Property, string >(); }
 
-  virtual unsigned long getArticleCount() noexcept
+  unsigned long getArticleCount() noexcept override
   { return 0; }
 
-  virtual unsigned long getWordCount() noexcept
+  unsigned long getWordCount() noexcept override
   { return 0; }
 
-  virtual sptr< WordSearchRequest > prefixMatch( wstring const &,
-                                                 unsigned long maxResults )
+  sptr< WordSearchRequest > prefixMatch( wstring const &,
+                                                 unsigned long maxResults ) override
     ;
 
-  virtual sptr< WordSearchRequest > findHeadwordsForSynonym( wstring const & )
+  sptr< WordSearchRequest > findHeadwordsForSynonym( wstring const & ) override
     ;
 
-  virtual sptr< DataRequest > getArticle( wstring const &,
+  sptr< DataRequest > getArticle( wstring const &,
                                           vector< wstring > const & alts,
                                           wstring const &,
-                                          bool )
+                                          bool ) override
     ;
 
-  virtual bool isLocalDictionary()
+  bool isLocalDictionary() override
   { return true; }
 
-  virtual vector< wstring > getAlternateWritings( const wstring & word ) noexcept;
+  vector< wstring > getAlternateWritings( const wstring & word ) noexcept override;
 
 protected:
 
-  virtual void loadIcon() noexcept;
+  void loadIcon() noexcept override;
 
 private:
 
@@ -199,7 +199,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class HunspellArticleRequest: public Dictionary::DataRequest
@@ -228,7 +228,7 @@ public:
 
   void run(); // Run from another thread by HunspellArticleRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -363,7 +363,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class HunspellHeadwordsRequest: public Dictionary::WordSearchRequest
@@ -392,7 +392,7 @@ public:
 
   void run(); // Run from another thread by HunspellHeadwordsRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -473,7 +473,7 @@ QVector< wstring > suggest( wstring & word, Mutex & hunspellMutex, Hunspell & hu
 
       wstring lowercasedWord = Folding::applySimpleCaseOnly( word );
 
-      static QRegExp cutStem( "^\\s*st:(((\\s+(?!\\w{2}:)(?!-)(?!\\+))|\\S+)+)" );
+      static QRegExp cutStem( R"(^\s*st:(((\s+(?!\w{2}:)(?!-)(?!\+))|\S+)+))" );
 
       for( vector< string >::size_type x = 0; x < suggestions.size(); ++x )
       {
@@ -538,7 +538,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class HunspellPrefixMatchRequest: public Dictionary::WordSearchRequest
@@ -567,7 +567,7 @@ public:
 
   void run(); // Run from another thread by HunspellPrefixMatchRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
