@@ -63,6 +63,22 @@ using BtreeIndexing::WordArticleLink;
 using BtreeIndexing::IndexedWords;
 using BtreeIndexing::IndexInfo;
 
+quint32 getLanguageId( const QString & lang )
+{
+  QString lstr = lang.left( 3 );
+
+  if( lstr.endsWith( QChar( '-' ) ) )
+    lstr.chop( 1 );
+
+  switch( lstr.size() )
+  {
+    case 2: return LangCoder::code2toInt( lstr.toLatin1().data() );
+    case 3: return LangCoder::findIdForLanguageCode3( lstr.toLatin1().data() );
+  }
+
+  return 0;
+}
+
 namespace {
 
 DEF_EX_STR( exCantReadFile, "Can't read file", Dictionary::Ex )
@@ -73,7 +89,7 @@ DEF_EX_STR( exDictzipError, "DICTZIP error", Dictionary::Ex )
 enum
 {
   Signature = 0x46584458, // XDXF on little-endian, FXDX on big-endian
-  CurrentFormatVersion = 5 + BtreeIndexing::FormatVersion + Folding::Version
+  CurrentFormatVersion = 6 + BtreeIndexing::FormatVersion + Folding::Version
 };
 
 enum ArticleFormat
@@ -147,60 +163,60 @@ public:
 
   ~XdxfDictionary();
 
-  virtual string getName() noexcept
+  string getName() noexcept override
   { return dictionaryName; }
 
-  virtual map< Dictionary::Property, string > getProperties() noexcept
+  map< Dictionary::Property, string > getProperties() noexcept override
   { return map< Dictionary::Property, string >(); }
 
-  virtual unsigned long getArticleCount() noexcept
+  unsigned long getArticleCount() noexcept override
   { return idxHeader.articleCount; }
 
-  virtual unsigned long getWordCount() noexcept
+  unsigned long getWordCount() noexcept override
   { return idxHeader.wordCount; }
 
-  inline virtual quint32 getLangFrom() const
+  inline quint32 getLangFrom() const override
   { return idxHeader.langFrom; }
 
-  inline virtual quint32 getLangTo() const
+  inline quint32 getLangTo() const override
   { return idxHeader.langTo; }
 
-  virtual sptr< Dictionary::DataRequest > getArticle( wstring const &,
+  sptr< Dictionary::DataRequest > getArticle( wstring const &,
                                                       vector< wstring > const & alts,
                                                       wstring const &,
-                                                      bool ignoreDiacritics )
+                                                      bool ignoreDiacritics ) override
     ;
 
-  virtual sptr< Dictionary::DataRequest > getResource( string const & name )
+  sptr< Dictionary::DataRequest > getResource( string const & name ) override
     ;
 
-  virtual QString const& getDescription();
+  QString const& getDescription() override;
 
-  virtual QString getMainFilename();
+  QString getMainFilename() override;
 
-  virtual sptr< Dictionary::DataRequest > getSearchResults( QString const & searchString,
+  sptr< Dictionary::DataRequest > getSearchResults( QString const & searchString,
                                                             int searchMode, bool matchCase,
                                                             int distanceBetweenWords,
                                                             int maxResults,
                                                             bool ignoreWordsOrder,
-                                                            bool ignoreDiacritics );
-  virtual void getArticleText( uint32_t articleAddress, QString & headword, QString & text );
+                                                            bool ignoreDiacritics ) override;
+  void getArticleText( uint32_t articleAddress, QString & headword, QString & text ) override;
 
-  virtual void makeFTSIndex(QAtomicInt & isCancelled, bool firstIteration );
+  void makeFTSIndex(QAtomicInt & isCancelled, bool firstIteration ) override;
 
-  virtual void setFTSParameters( Config::FullTextSearch const & fts )
+  void setFTSParameters( Config::FullTextSearch const & fts ) override
   {
     can_FTS = fts.enabled
               && !fts.disabledTypes.contains( "XDXF", Qt::CaseInsensitive )
               && ( fts.maxDictionarySize == 0 || getArticleCount() <= fts.maxDictionarySize );
   }
 
-  virtual uint32_t getFtsIndexVersion()
+  uint32_t getFtsIndexVersion() override
   { return 1; }
 
 protected:
 
-  void loadIcon() noexcept;
+  void loadIcon() noexcept override;
 
 private:
 
@@ -454,7 +470,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class XdxfArticleRequest: public Dictionary::DataRequest
@@ -482,7 +498,7 @@ public:
 
   void run(); // Run from another thread by XdxfArticleRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -700,22 +716,22 @@ protected:
 
   dictData *dz;
 
-  virtual bool isSequential () const
+  bool isSequential () const override
   { return false; } // Which is a lie, but else pos() won't work
 
-  bool waitForReadyRead ( int )
+  bool waitForReadyRead ( int ) override
   { return !gzeof( gz ); }
 
-  qint64 bytesAvailable() const
+  qint64 bytesAvailable() const override
   {
      return ( gzeof( gz ) ? 0 : 1 ) + QIODevice::bytesAvailable();
   }
 
-  virtual qint64 readData( char * data, qint64 maxSize );
+  qint64 readData( char * data, qint64 maxSize ) override;
 
-  virtual bool atEnd() const;
+  bool atEnd() const override;
 
-  virtual qint64 writeData ( const char * /*data*/, qint64 /*maxSize*/ )
+  qint64 writeData ( const char * /*data*/, qint64 /*maxSize*/ ) override
   { return -1; }
 };
 
@@ -983,7 +999,7 @@ public:
     hasExited.release();
   }
 
-  virtual void run();
+  void run() override;
 };
 
 class XdxfResourceRequest: public Dictionary::DataRequest
@@ -1010,7 +1026,7 @@ public:
 
   void run(); // Run from another thread by XdxfResourceRequestRunnable
 
-  virtual void cancel()
+  void cancel() override
   {
     isCancelled.ref();
   }
@@ -1208,25 +1224,19 @@ vector< sptr< Dictionary::Class > > makeDictionaries(
               // Read the xdxf
 
               string str = stream.attributes().value( "lang_from" ).toString().toLatin1().data();
-
-              if ( str.size() > 3 )
-                str.resize( 3 );
-
-              idxHeader.langFrom = LangCoder::findIdForLanguageCode3( str.c_str() );
+              if( !str.empty() )
+                idxHeader.langFrom = getLanguageId( str.c_str() );
 
               str = stream.attributes().value( "lang_to" ).toString().toLatin1().data();
-
-              if ( str.size() > 3 )
-                str.resize( 3 );
-
-              idxHeader.langTo = LangCoder::findIdForLanguageCode3( str.c_str() );
-
-              bool isLogical = ( stream.attributes().value( "format" ) == u"logical" );
+              if( !str.empty() )
+                idxHeader.langTo = getLanguageId( str.c_str() );
 
               QRegExp regNum( "\\d+" );
               regNum.indexIn( stream.attributes().value( "revision" ).toString() );
               idxHeader.revisionNumber = regNum.cap().toUInt();
 
+              bool isLogical = ( stream.attributes().value( "format" ) == u"logical" || idxHeader.revisionNumber >= 34 );
+
               idxHeader.articleFormat = isLogical ? Logical : Visual;
 
               unsigned articleCount = 0, wordCount = 0;
@@ -1269,6 +1279,13 @@ vector< sptr< Dictionary::Class > > makeDictionaries(
                     // todo implement adding other information to the description like <publisher>, <authors>, <file_ver>, <creation_date>, <last_edited_date>, <dict_edition>, <publishing_date>, <dict_src_url> 
                     QString desc = readXhtmlData( stream );
 
+                    if( isLogical )
+                    {
+                      desc = desc.simplified();
+                      QRegularExpression br( "<br\\s*>\\s*</br>" );
+                      desc.replace( br, QString("\n") );
+                    }
+
                     if ( dictionaryDescription.isEmpty() )
                     {
                       dictionaryDescription = desc;
@@ -1286,6 +1303,36 @@ vector< sptr< Dictionary::Class > > makeDictionaries(
                     }
                   }
                   else
+                  if( stream.name() == u"languages" )
+                  {
+                    while( !( stream.isEndElement() && stream.name() == u"languages" ) && !stream.atEnd() )
+                    {
+                      if( !stream.readNext() )
+                        break;
+                      if ( stream.isStartElement() )
+                      {
+                        if( stream.name() == u"from" )
+                        {
+                          if( idxHeader.langFrom == 0 )
+                          {
+                            QString lang = stream.attributes().value( "xml:lang" ).toString();
+                            idxHeader.langFrom = getLanguageId( lang );
+                          }
+                        }
+                        else if( stream.name() == u"to" )
+                        {
+                          if( idxHeader.langTo == 0 )
+                          {
+                            QString lang = stream.attributes().value( "xml:lang" ).toString();
+                            idxHeader.langTo = getLanguageId( lang );
+                          }
+                        }
+                      }
+                      else if ( stream.isEndElement() && stream.name() == u"languages" )
+                        break;
+                    }
+                  }
+                  else
                   if ( stream.name() == u"abbreviations" )
                   {
                     QString s;
